/manager

Tomcat Web Application Manager

Message: |
    OK

Manager
List Applications | HTML Manager Help | Manager Help | Server Status

Applications
Path | Display Name | Running | Sessions | Commands
/ |  | true | 0 | Start Stop Reload Undeploy
with idle ≥ minutes
/host-manager | Tomcat Manager Application | true | 0 | Start Stop Reload Undeploy
with idle ≥ minutes
/manager | Tomcat Manager Application | true | 1 | Start Stop Reload Undeploy
with idle ≥ minutes

Deploy
Deploy directory or WAR file located on server
Context Path (required): |
XML Configuration file URL: |
WAR or Directory URL: |
WAR file to deploy
Select WAR file to upload |

Server Information
Tomcat Version | JVM Version | JVM Vendor | OS Name | OS Version | OS Architecture
Apache Tomcat/6.0.24 | 1.6.0_26-b03 | Sun Microsystems Inc. | Linux | 2.6.32-31-generic | i386

Copyright © 1999-2010, Apache Software Foundation